OneOrMany

Enum OneOrMany 

pub enum OneOrMany<T> {
    One(T),
    Many(Vec<T>),
}
A non-specific holder for an option which can either be a single thing, or multiple instances of that thing.

Variants



One(T)



Many(Vec<T>)